@@ -118,6 +118,14 @@ pub mod telemetry;
 /// ```
 pub use macroquad_macro::main;
 
+/// #[macroquad::test] fn test() {}
+///
+/// Very similar to macroquad::main
+/// Right now it will still spawn a window, just like ::main, therefore
+/// is not really usefull for anything than developping macroquad itself
+#[doc(hidden)]
+pub use macroquad_macro::test;
+
 /// Cross platform random generator.
 pub mod rand {
     pub use quad_rand::*;
@@ -394,6 +402,14 @@ impl Context {
 #[no_mangle]
 static mut CONTEXT: Option<Context> = None;
 
+// unfortunately #[cfg(test)] do not work with integration tests
+// so this module should be publicly available
+#[doc(hidden)]
+pub mod test {
+    pub static mut MUTEX: Option<std::sync::Mutex<()>> = None;
+    pub static ONCE: std::sync::Once = std::sync::Once::new();
+}
+
 fn get_context() -> &'static mut Context {
     unsafe { CONTEXT.as_mut().unwrap_or_else(|| panic!()) }
 }
